@@ -70,7 +70,7 @@ class AbstractInterface():
     start_state = int(self.get_config_value('enable-on-startup'))
     self.__switch_state(start_state)
     if start_state or self.force_startup_mode:
-      self.__switch_mode(self.get_modes().index(self.get_config_value('mode-on-startup')), True)
+      self.__switch_mode(self.get_modes().index(self.get_config_value('mode-on-startup')), start_state == InterfaceState.off)
 
     #print self.__name, self.state['value'], self.state['mode'], self.state['strength']
     #self.__show_switch_dialog()
